@@ -10,22 +10,22 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.12';
-$DATE = '2004/05/19';
+$VERSION = '0.13';
+$DATE = '2004/05/20';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.12 2004/05/19), 'revised 0.11'],
-    'MANIFEST' => [qw(0.12 2004/05/19), 'generated, replaces 0.11'],
-    'Makefile.PL' => [qw(0.12 2004/05/19), 'generated, replaces 0.11'],
-    'README' => [qw(0.12 2004/05/19), 'generated, replaces 0.11'],
-    'lib/Test/STDmaker.pm' => [qw(1.15 2004/05/19), 'revised 1.14'],
-    'lib/Test/STDmaker/Check.pm' => [qw(1.11 2004/05/19), 'revised 1.1'],
-    'lib/Test/STDmaker/Demo.pm' => [qw(1.12 2004/05/19), 'revised 1.11'],
-    'lib/Test/STDmaker/STD.pm' => [qw(1.1 2004/05/19), 'revised 1.09'],
-    'lib/Test/STDmaker/Verify.pm' => [qw(1.12 2004/05/19), 'revised 1.11'],
-    'lib/Test/STD/PerlSTD.pm' => [qw(1.08 2004/05/19), 'revised 1.07'],
+    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.13 2004/05/20), 'revised 0.12'],
+    'MANIFEST' => [qw(0.13 2004/05/20), 'generated, replaces 0.12'],
+    'Makefile.PL' => [qw(0.13 2004/05/20), 'generated, replaces 0.12'],
+    'README' => [qw(0.13 2004/05/20), 'generated, replaces 0.12'],
+    'lib/Test/STDmaker.pm' => [qw(1.16 2004/05/20), 'revised 1.15'],
+    'lib/Test/STDmaker/Check.pm' => [qw(1.12 2004/05/20), 'revised 1.11'],
+    'lib/Test/STDmaker/Demo.pm' => [qw(1.13 2004/05/20), 'revised 1.12'],
+    'lib/Test/STDmaker/STD.pm' => [qw(1.1 2004/05/19), 'unchanged'],
+    'lib/Test/STDmaker/Verify.pm' => [qw(1.13 2004/05/20), 'revised 1.12'],
+    'lib/Test/STD/PerlSTD.pm' => [qw(1.08 2004/05/19), 'unchanged'],
     't/Test/STDmaker/STDmaker.d' => [qw(0.12 2004/05/18), 'unchanged'],
     't/Test/STDmaker/STDmaker.pm' => [qw(0.1 2004/05/18), 'unchanged'],
     't/Test/STDmaker/STDmaker.t' => [qw(0.12 2004/05/18), 'unchanged'],
@@ -33,25 +33,25 @@ use vars qw(%INVENTORY);
     't/Test/STDmaker/tg2A.pm' => [qw(0.03 2004/05/14), 'unchanged'],
     't/Test/STDmaker/tg2B.pm' => [qw(0.04 2004/05/14), 'unchanged'],
     't/Test/STDmaker/tgA0.pm' => [qw(0.05 2004/05/18), 'unchanged'],
-    't/Test/STDmaker/tgA1.pm' => [qw(0.05 2004/05/19), 'new'],
+    't/Test/STDmaker/tgA1.pm' => [qw(0.05 2004/05/19), 'unchanged'],
     't/Test/STDmaker/tgA2.pm' => [qw(0.05 2004/05/18), 'unchanged'],
     't/Test/STDmaker/tgA2A2.txt' => [qw(0.1 2004/05/14), 'unchanged'],
     't/Test/STDmaker/tgA2A3.txt' => [qw(0.10 2004/05/14), 'unchanged'],
     't/Test/STDmaker/tgA2B.txt' => [qw(0.08 2004/05/14), 'unchanged'],
     't/Test/STDmaker/tgA2C.txt' => [qw(0.09 2004/05/14), 'unchanged'],
     't/Test/STDmaker/tgB0.pm' => [qw(0.02 2004/05/18), 'unchanged'],
-    't/Test/STDmaker/tgB1.pm' => [qw(0.01 2004/05/19), 'new'],
+    't/Test/STDmaker/tgB1.pm' => [qw(0.01 2004/05/19), 'unchanged'],
     't/Test/STDmaker/tgB2.pm' => [qw(0.02 2004/05/18), 'unchanged'],
     't/Test/STDmaker/tgB2.txt' => [qw(0.09 2004/05/14), 'unchanged'],
     't/Test/STDmaker/tgC0.pm' => [qw(0.04 2004/05/18), 'unchanged'],
-    't/Test/STDmaker/tgC1.pm' => [qw(0.01 2004/05/19), 'new'],
+    't/Test/STDmaker/tgC1.pm' => [qw(0.01 2004/05/19), 'unchanged'],
     't/Test/STDmaker/tgC2.pm' => [qw(0.04 2004/05/18), 'unchanged'],
-    't/Test/STDmaker/tmake.pl' => [qw(1.06 2004/05/19), 'unchanged'],
-    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.13 2004/05/19), 'unchanged'],
-    't/Test/STDmaker/Test/Tech.pm' => [qw(1.26 2004/05/19), 'revised 1.25'],
-    't/Test/STDmaker/Data/Secs2.pm' => [qw(1.24 2004/05/19), 'revised 1.23'],
-    't/Test/STDmaker/Data/Str2Num.pm' => [qw(0.05 2004/05/19), 'new'],
-    't/Test/STDmaker/Data/Startup.pm' => [qw(0.06 2004/05/19), 'new'],
+    't/Test/STDmaker/tmake.pl' => [qw(1.06 2004/05/20), 'unchanged'],
+    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.14 2004/05/20), 'revised 1.13'],
+    't/Test/STDmaker/Test/Tech.pm' => [qw(1.26 2004/05/20), 'unchanged'],
+    't/Test/STDmaker/Data/Secs2.pm' => [qw(1.25 2004/05/20), 'revised 1.24'],
+    't/Test/STDmaker/Data/Str2Num.pm' => [qw(0.06 2004/05/20), 'revised 0.05'],
+    't/Test/STDmaker/Data/Startup.pm' => [qw(0.06 2004/05/20), 'unchanged'],
 
 );
 
@@ -82,11 +82,11 @@ Docs::Site_SVD::Test_STDmaker - generate test scripts, demo scripts from a test
 
  Docs::Site_SVD::Test_STDmaker - generate test scripts, demo scripts from a test description short hand
 
- Revision: L
+ Revision: M
 
- Version: 0.12
+ Version: 0.13
 
- Date: 2004/05/19
+ Date: 2004/05/20
 
  Prepared for: General Public 
 
@@ -155,8 +155,6 @@ a US Department of Defense (DOD)
 Software Test Description (L<STD|Docs::US_DOD::STD>) 
 Data Item Description (DID).
 
-=item 5
-
 =back
 
 The C<Test::STDmaker> package relieves the designer
@@ -177,7 +175,7 @@ further detail on the text database fields and the processing.
 
 =head2 1.3 Document overview.
 
-This document releases Test::STDmaker version 0.12
+This document releases Test::STDmaker version 0.13
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -192,7 +190,7 @@ system file specification.
 
 This document releases the file 
 
- Test-STDmaker-0.12.tar.gz
+ Test-STDmaker-0.13.tar.gz
 
 found at the following repository(s):
 
@@ -279,16 +277,16 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_STDmaker.pm                           0.12    2004/05/19 revised 0.11
- MANIFEST                                                     0.12    2004/05/19 generated, replaces 0.11
- Makefile.PL                                                  0.12    2004/05/19 generated, replaces 0.11
- README                                                       0.12    2004/05/19 generated, replaces 0.11
- lib/Test/STDmaker.pm                                         1.15    2004/05/19 revised 1.14
- lib/Test/STDmaker/Check.pm                                   1.11    2004/05/19 revised 1.1
- lib/Test/STDmaker/Demo.pm                                    1.12    2004/05/19 revised 1.11
- lib/Test/STDmaker/STD.pm                                     1.1     2004/05/19 revised 1.09
- lib/Test/STDmaker/Verify.pm                                  1.12    2004/05/19 revised 1.11
- lib/Test/STD/PerlSTD.pm                                      1.08    2004/05/19 revised 1.07
+ lib/Docs/Site_SVD/Test_STDmaker.pm                           0.13    2004/05/20 revised 0.12
+ MANIFEST                                                     0.13    2004/05/20 generated, replaces 0.12
+ Makefile.PL                                                  0.13    2004/05/20 generated, replaces 0.12
+ README                                                       0.13    2004/05/20 generated, replaces 0.12
+ lib/Test/STDmaker.pm                                         1.16    2004/05/20 revised 1.15
+ lib/Test/STDmaker/Check.pm                                   1.12    2004/05/20 revised 1.11
+ lib/Test/STDmaker/Demo.pm                                    1.13    2004/05/20 revised 1.12
+ lib/Test/STDmaker/STD.pm                                     1.1     2004/05/19 unchanged
+ lib/Test/STDmaker/Verify.pm                                  1.13    2004/05/20 revised 1.12
+ lib/Test/STD/PerlSTD.pm                                      1.08    2004/05/19 unchanged
  t/Test/STDmaker/STDmaker.d                                   0.12    2004/05/18 unchanged
  t/Test/STDmaker/STDmaker.pm                                  0.1     2004/05/18 unchanged
  t/Test/STDmaker/STDmaker.t                                   0.12    2004/05/18 unchanged
@@ -296,25 +294,25 @@ consists of the following files:
  t/Test/STDmaker/tg2A.pm                                      0.03    2004/05/14 unchanged
  t/Test/STDmaker/tg2B.pm                                      0.04    2004/05/14 unchanged
  t/Test/STDmaker/tgA0.pm                                      0.05    2004/05/18 unchanged
- t/Test/STDmaker/tgA1.pm                                      0.05    2004/05/19 new
+ t/Test/STDmaker/tgA1.pm                                      0.05    2004/05/19 unchanged
  t/Test/STDmaker/tgA2.pm                                      0.05    2004/05/18 unchanged
  t/Test/STDmaker/tgA2A2.txt                                   0.1     2004/05/14 unchanged
  t/Test/STDmaker/tgA2A3.txt                                   0.10    2004/05/14 unchanged
  t/Test/STDmaker/tgA2B.txt                                    0.08    2004/05/14 unchanged
  t/Test/STDmaker/tgA2C.txt                                    0.09    2004/05/14 unchanged
  t/Test/STDmaker/tgB0.pm                                      0.02    2004/05/18 unchanged
- t/Test/STDmaker/tgB1.pm                                      0.01    2004/05/19 new
+ t/Test/STDmaker/tgB1.pm                                      0.01    2004/05/19 unchanged
  t/Test/STDmaker/tgB2.pm                                      0.02    2004/05/18 unchanged
  t/Test/STDmaker/tgB2.txt                                     0.09    2004/05/14 unchanged
  t/Test/STDmaker/tgC0.pm                                      0.04    2004/05/18 unchanged
- t/Test/STDmaker/tgC1.pm                                      0.01    2004/05/19 new
+ t/Test/STDmaker/tgC1.pm                                      0.01    2004/05/19 unchanged
  t/Test/STDmaker/tgC2.pm                                      0.04    2004/05/18 unchanged
- t/Test/STDmaker/tmake.pl                                     1.06    2004/05/19 unchanged
- t/Test/STDmaker/Text/Scrub.pm                                1.13    2004/05/19 unchanged
- t/Test/STDmaker/Test/Tech.pm                                 1.26    2004/05/19 revised 1.25
- t/Test/STDmaker/Data/Secs2.pm                                1.24    2004/05/19 revised 1.23
- t/Test/STDmaker/Data/Str2Num.pm                              0.05    2004/05/19 new
- t/Test/STDmaker/Data/Startup.pm                              0.06    2004/05/19 new
+ t/Test/STDmaker/tmake.pl                                     1.06    2004/05/20 unchanged
+ t/Test/STDmaker/Text/Scrub.pm                                1.14    2004/05/20 revised 1.13
+ t/Test/STDmaker/Test/Tech.pm                                 1.26    2004/05/20 unchanged
+ t/Test/STDmaker/Data/Secs2.pm                                1.25    2004/05/20 revised 1.24
+ t/Test/STDmaker/Data/Str2Num.pm                              0.06    2004/05/20 revised 0.05
+ t/Test/STDmaker/Data/Startup.pm                              0.06    2004/05/20 unchanged
 
 
 =head2 3.3 Changes
@@ -512,6 +510,31 @@ Changed C<Test::STDmaker::Demo> and C<Test::STDmaker::Check> so they load
 C<Test::Tech> after setting up C<@INC>. Else missing finding some
 test library modules because they are not in the C<INC> path.
 
+=item Test-STDmaker-0.13
+
+Test Failure:
+
+ Subject: FAIL Test-STDmaker-0.12 ppc-linux 2.4.19-4a 
+ From: alian@cpan.org (CPAN Tester + CPAN++ automate) 
+
+Perl lib version (v5.8.4) doesn't match executable version (v5.6.0) at 
+/usr/local/perl-5.8.4/lib/5.8.4/ppc-linux/Config.pm line 32.
+Compilation failed in require at /usr/local/perl-5.8.4/lib/5.8.4/FindBin.pm line 97.
+BEGIN failed--compilation aborted at /usr/local/perl-5.8.4/lib/5.8.4/FindBin.pm line 97.
+Compilation failed in require at temp.pl line 8.
+
+Analysis:
+
+Line 8 is a backtick `perl $command`. To get to line 8 everything must
+going well. Thus, suspect that the test harness perl executable is 
+different than the command line perl executable. 
+
+Corrective Action
+
+Introduced the C<perl_command> subroutine that uses C<$^X> to return the current executable Perl.
+Use the results of this subroutine instead of 'perl' in backticks.
+See how it goes.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -550,13 +573,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
-Right click on 'Test-STDmaker-0.12.tar.gz' and download to a temporary
+Right click on 'Test-STDmaker-0.13.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip Test-STDmaker-0.12.tar.gz
- tar -xf Test-STDmaker-0.12.tar
+ gunzip Test-STDmaker-0.13.tar.gz
+ tar -xf Test-STDmaker-0.13.tar
  perl Makefile.PL
  $make test
  $make install
@@ -660,7 +683,6 @@ Software Version Description
 
 =item L<Tie::FormD|Tie::Form>
 
-
 =item L<Test::Tech|Test::Tech>
 
 =item L<Test|Test>
@@ -708,10 +730,10 @@ __DATA__
 DISTNAME: Test-STDmaker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.12^
+VERSION : 0.13^
 FREEZE: 1^
-PREVIOUS_RELEASE: 0.11^
-REVISION: L^
+PREVIOUS_RELEASE: 0.12^
+REVISION: M^
 
 PREVIOUS_DISTNAME:  ^
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -816,8 +838,6 @@ a US Department of Defense (DOD)
 Software Test Description (L<STD|Docs::US_DOD::STD>) 
 Data Item Description (DID).
 
-\=item 5
-
 \=back
 
 The C<Test::STDmaker> package relieves the designer
@@ -1032,6 +1052,31 @@ Changed C<Test::STDmaker::Demo> and C<Test::STDmaker::Check> so they load
 C<Test::Tech> after setting up C<@INC>. Else missing finding some
 test library modules because they are not in the C<INC> path.
 
+\=item Test-STDmaker-0.13
+
+Test Failure:
+
+ Subject: FAIL Test-STDmaker-0.12 ppc-linux 2.4.19-4a 
+ From: alian@cpan.org (CPAN Tester + CPAN++ automate) 
+
+Perl lib version (v5.8.4) doesn't match executable version (v5.6.0) at 
+/usr/local/perl-5.8.4/lib/5.8.4/ppc-linux/Config.pm line 32.
+Compilation failed in require at /usr/local/perl-5.8.4/lib/5.8.4/FindBin.pm line 97.
+BEGIN failed--compilation aborted at /usr/local/perl-5.8.4/lib/5.8.4/FindBin.pm line 97.
+Compilation failed in require at temp.pl line 8.
+
+Analysis:
+
+Line 8 is a backtick `perl $command`. To get to line 8 everything must
+going well. Thus, suspect that the test harness perl executable is 
+different than the command line perl executable. 
+
+Corrective Action
+
+Introduced the C<perl_command> subroutine that uses C<$^^X> to return the current executable Perl.
+Use the results of this subroutine instead of 'perl' in backticks.
+See how it goes.
+
 \=back
 
 ^
@@ -1199,7 +1244,6 @@ SEE_ALSO:
 
 \=item L<Tie::FormD|Tie::Form>
 
-
 \=item L<Test::Tech|Test::Tech>
 
 \=item L<Test|Test>
@@ -1254,6 +1298,14 @@ HTML:
 
 
 
+
+
+
+
+
+
+
+
 
 
 
